@@ -54,7 +54,8 @@ int main(int argc, char **argv)
                 start= 1,       /* Starting value for signature curve        */
                 end=MAXINT,     /* Ending value for signature curve          */
                 streamopt=0,    /* Streaming mode flag                       */
-                reset_connection;/* Reset the connection between trials      */
+                reset_connection,/* Reset the connection between trials      */
+		debug_wait=0;	/* spin and wait for a debugger		     */
    
     ArgStruct   args;           /* Arguments for all the calls               */
 
@@ -84,6 +85,8 @@ int main(int argc, char **argv)
     args.soffset=0; /* default to no offsets */
     args.roffset=0; 
     args.syncflag=0; /* use normal mpi_send */
+    args.use_sdp=0; /* default to no SDP */
+    args.port = DEFPORT; /* just in case the user doesn't set this. */
 
 
     /* TCGMSG launches NPtcgmsg with a -master master_hostname
@@ -94,10 +97,13 @@ int main(int argc, char **argv)
 #if ! defined(TCGMSG)
 
     /* Parse the arguments. See Usage for description */
-    while ((c = getopt(argc, argv, "SO:rIiPszgfaB2h:p:o:l:u:b:m:n:t:c:d:D:")) != -1)
+    while ((c = getopt(argc, argv, "AXSO:rIiPszgfaB2h:p:o:l:u:b:m:n:t:c:d:D:P:")) != -1)
     {
         switch(c)
         {
+	    case 'A':
+		      args.use_sdp=1;
+		      break;
             case 'O':
                       strcpy(s2,optarg);
                       strcpy(delim,",");
@@ -142,7 +148,7 @@ int main(int argc, char **argv)
 
             case 's': streamopt = 1;
                       printf("Streaming in one direction only.\n\n");
-#if defined(TCP) && ! defined(INFINIBAND) 
+#if defined(TCP) && ! defined(INFINIBAND) && !defined(OPENIB)
                       printf("Sockets are reset between trials to avoid\n");
                       printf("degradation from a collapsing window size.\n\n");
 #endif
@@ -168,7 +174,7 @@ int main(int argc, char **argv)
             case 'u': end = atoi(optarg);
                       break;
 
-#if defined(TCP) && ! defined(INFINIBAND)
+#if defined(TCP) && ! defined(INFINIBAND) && !defined(OPENIB)
             case 'b': /* -b # resets the buffer size, -b 0 keeps system defs */
                       args.prot.sndbufsz = args.prot.rcvbufsz = atoi(optarg);
                       break;
@@ -178,7 +184,7 @@ int main(int argc, char **argv)
                          /* end will be maxed at sndbufsz+rcvbufsz */
                       printf("Passing data in both directions simultaneously.\n");
                       printf("Output is for the combined bandwidth.\n");
-#if defined(TCP) && ! defined(INFINIBAND)
+#if defined(TCP) && ! defined(INFINIBAND) && !defined(OPENIB)
                       printf("The socket buffer size limits the maximum test size.\n\n");
 #endif
                       if( streamopt ) {
@@ -270,7 +276,34 @@ int main(int argc, char **argv)
                           exit(-1);
                       }
                       break;
+#endif
 
+#if defined(OPENIB)
+            case 'm': switch(atoi(optarg)) {
+                        case 256: args.prot.ib_mtu = IBV_MTU_256;
+                          break;
+                        case 512: args.prot.ib_mtu = IBV_MTU_512;
+                          break;
+                        case 1024: args.prot.ib_mtu = IBV_MTU_1024;
+                          break;
+                        case 2048: args.prot.ib_mtu = IBV_MTU_2048;
+                          break;
+                        case 4096: args.prot.ib_mtu = IBV_MTU_4096;
+                          break;
+                        default: 
+                          fprintf(stderr, "Invalid MTU size, must be one of "
+                                          "256, 512, 1024, 2048, 4096\n");
+                          exit(-1);
+                      }
+                      break;
+#endif
+
+#if defined(OPENIB)
+            case 'D': args.prot.device_and_port = strdup(optarg);
+                      break;
+#endif
+
+#if defined(OPENIB) || defined(INFINIBAND)
             case 't': if( !strcmp(optarg, "send_recv") ) {
                          printf("Using Send/Receive communications\n");
                          args.prot.commtype = NP_COMM_SENDRECV;
@@ -313,15 +346,22 @@ int main(int argc, char **argv)
                       }
                       break;
 #endif
+	    case 'P': 
+		      args.port = atoi(optarg);
+		      break;
 
             case 'n': nrepeat_const = atoi(optarg);
                       break;
 
-#if defined(TCP) && ! defined(INFINIBAND)
+#if defined(TCP) && ! defined(INFINIBAND) && !defined(OPENIB)
             case 'r': args.reset_conn = 1;
                       printf("Resetting connection after every trial\n");
                       break;
 #endif
+	    case 'X': debug_wait = 1;
+		      printf("Enableing debug wait!\n");
+		      printf("Attach to pid %d and set debug_wait to 0 to conttinue\n", getpid());
+		      break;
 
             default: 
                      PrintUsage(); 
@@ -329,9 +369,12 @@ int main(int argc, char **argv)
        }
    }
 
+   while(debug_wait){
+	   for(i=0;i<10000;i++){};
+   	};
 #endif /* ! defined TCGMSG */
 
-#if defined(INFINIBAND)
+#if defined(OPENIB) || defined(INFINIBAND)
    asyncReceive = 1;
    fprintf(stderr, "Preposting asynchronous receives (required for Infiniband)\n");
    if(args.bidir && (
@@ -369,7 +412,6 @@ int main(int argc, char **argv)
        exit(420132);
    }
    args.nbuff = TRIALS;
-   args.port = DEFPORT;
 
    Setup(&args);
 
@@ -377,7 +419,7 @@ int main(int argc, char **argv)
       end = args.upper;
       if( args.tr ) {
          printf("The upper limit is being set to %d Bytes\n", end);
-#if defined(TCP) && ! defined(INFINIBAND)
+#if defined(TCP) && ! defined(INFINIBAND) && !defined(OPENIB)
          printf("due to socket buffer size limitations\n\n");
 #endif
    }  }
@@ -990,15 +1032,15 @@ void VerifyIntegrity(ArgStruct *p)
 void PrintUsage()
 {
     printf("\n NETPIPE USAGE \n\n");
-#if ! defined(INFINIBAND)
+#if ! defined(INFINIBAND) && !defined(OPENIB)
     printf("a: asynchronous receive (a.k.a. preposted receive)\n");
 #endif
     printf("B: burst all preposts before measuring performance\n");
-#if defined(TCP) && ! defined(INFINIBAND)
+#if (defined(TCP) || defined(TCP6)) && ! defined(INFINIBAND)
     printf("b: specify TCP send/receive socket buffer sizes\n");
 #endif
 
-#if defined(INFINIBAND)
+#if defined(INFINIBAND) || defined(OPENIB)
     printf("c: specify type of completion <-c type>\n"
            "   valid types: local_poll, vapi_poll, event\n"
            "   default: local_poll\n");
@@ -1010,7 +1052,7 @@ void PrintUsage()
     printf("   all MPI-2 implementations\n");
 #endif
 
-#if defined(TCP) || defined(INFINIBAND)
+#if defined(TCP) || defined(TCP6) || defined(SCTP) || defined(SCTP6) || defined(INFINIBAND) || defined(OPENIB)
     printf("h: specify hostname of the receiver <-h host>\n");
 #endif
 
@@ -1019,7 +1061,7 @@ void PrintUsage()
     printf("i: Do an integrity check instead of measuring performance\n");
     printf("l: lower bound start value e.g. <-l 1>\n");
 
-#if defined(INFINIBAND)
+#if defined(INFINIBAND) || defined(OPENIB)
     printf("m: set MTU for Infiniband adapter <-m mtu_size>\n");
     printf("   valid sizes: 256, 512, 1024, 2048, 4096 (default 1024)\n");
 #endif
@@ -1030,7 +1072,7 @@ void PrintUsage()
     printf("p: set the perturbation number <-p 1>\n"
            "   (default = 3 Bytes, set to 0 for no perturbations)\n");
 
-#if defined(TCP) && ! defined(INFINIBAND)
+#if (defined(TCP) || defined(TCP6) || defined(SCTP) || defined(SCTP6)) && ! defined(INFINIBAND) && !defined(OPENIB)
     printf("r: reset sockets for every trial\n");
 #endif
 
@@ -1039,12 +1081,23 @@ void PrintUsage()
     printf("S: Use synchronous sends.\n");
 #endif
 
-#if defined(INFINIBAND)
+#if defined(INFINIBAND) || defined(OPENIB)
     printf("t: specify type of communications <-t type>\n"
            "   valid types: send_recv, send_recv_with_imm,\n"
            "                rdma_write, rdma_write_with_imm\n"
            "   defaul: send_recv\n");
 #endif
+#if defined(OPENIB)
+    printf("D: specify an OpenFabrics device/port combination\n"
+           "   to use on the local host.  For example:\n"
+           "      -D mthca0:1\n"
+           "   Uses the first port on the \"mthca0\" device\n"
+           "   (NOTE: ports are indexed from 1, not 0)\n"
+           "      -D mthca1\n"
+           "   Uses the first active port on the mtcha1 device\n"
+           "   No specification will result in using the first\n"
+           "   active port on any valid device.\n");
+#endif
     
     printf("u: upper bound stop value e.g. <-u 1048576>\n");
  
@@ -1053,11 +1106,15 @@ void PrintUsage()
 #endif
 
     printf("2: Send data in both directions at the same time.\n");
+    printf("P: Set the port number to one other than the default.\n");
 #if defined(MPI)
     printf("   May need to use -a to choose asynchronous communications for MPI/n");
 #endif
-#if defined(TCP) && !defined(INFINIBAND)
-    printf("   The maximum test size is limited by the TCP buffer size/n");
+#if (defined(TCP) || defined(TCP6) || defined(SCTP) || defined (SCTP6)) && !defined(INFINIBAND) && !defined(OPENIB)
+    printf("   The maximum test size is limited by the TCP buffer size\n");
+#endif
+#if defined(TCP)
+    printf("A: Use SDP Address familty (AF_INET_SDP)\n");
 #endif
     printf("\n");
 }
@@ -1131,7 +1188,7 @@ void InitBufferData(ArgStruct *p, int nbytes, int soffset, int roffset)
 
     memset(p->s_buff, 'b', nbytes+soffset);
 }
-#if !defined(INFINIBAND) && !defined(ARMCI) && !defined(LAPI) && !defined(GPSHMEM) && !defined(SHMEM) && !defined(GM)
+#if !defined(OPENIB) && !defined(INFINIBAND) && !defined(ARMCI) && !defined(LAPI) && !defined(GPSHMEM) && !defined(SHMEM) && !defined(GM) 
 
 void MyMalloc(ArgStruct *p, int bufflen, int soffset, int roffset)
 {
